API definitions, errors, clients, and structs sent across the wire.
Modules
- auth
- Authentication and User Signup.
- fiat_
rates - Data types returned from the fiat exchange rate API. Data types returned from the fiat exchange rate API.
- models
- API models which don’t fit anywhere else.
- provision
- Data types specific to provisioning.
- revocable_
clients - The revocable clients interface for handshake-time revocation checks.
The
GetRevocableClientStatusinterface for handshake-time revocation checks. - test_
event TestEvent.- user
- User ID-like types:
User,UserPk,NodePk,Scid - version
- Data types which relate to node versions:
NodeEnclave,MeasurementStruct
Structs
Type Aliases
- MegaId
- A randomly generated id for each mega node.