Module auth

Module auth 

Authentication and User Signup.

Structs

BearerAuthRequest
A client’s request for a new BearerAuthToken.
BearerAuthRequestWireV1
A user client’s request for auth token with certain restrictions.
BearerAuthRequestWireV2
A user client’s request for auth token with certain restrictions.
BearerAuthResponse
BearerAuthToken
An opaque bearer auth token for authenticating user clients against lexe infra as a particular UserPk.
TokenWithExpiration
A BearerAuthToken and its expected expiration time, or None if the token never expires.
UserSignupRequestWireV1
UserSignupRequestWireV2

Enums

BearerAuthRequestWire
A client’s request for a new BearerAuthToken.
Error
Scope
The allowed API scope for the bearer auth token.
UserSignupRequestWire
The inner, signed part of the request a new user makes when they first sign up. We use this to prove the user owns both their claimed UserPk and NodePk.