Module models

Module models 

API models which don’t fit anywhere else.

Structs

BroadcastedTx
The user node or LSP broadcasted an on-chain transaction.
BroadcastedTxInfo
SignMsgRequest
A request to sign a message using the node ID secret key.
SignMsgResponse
Status
A response to a status check.
VerifyMsgRequest
A request to verify that a message was signed by the given public key.
VerifyMsgResponse