pub enum RevocableClientStatus {
Valid,
Revoked,
Expired,
}Expand description
The handshake-time status of a revocable client cert.
Variants
Valid
Not revoked and not expired — accept the cert.
NOTE: This only means that the client is allowed to connect; it does NOT mean that the client is authorized to do whatever it is asking to do. Client scopes and budgets must still be enforced at a higher level.
Revoked
The client was revoked. Revocation is permanent.
Expired
The client is expired as of the queried time.