pub struct CreateRevocableClientRequest {
pub expires_at: Option<TimestampMs>,
pub label: Option<String>,
pub scope: Scope,
}Expand description
A request to create a new revocable client.
Fields
expires_at: Option<TimestampMs>The expiration after which the node should reject this client.
None indicates that the client will never expire (use carefully!).
label: Option<String>Optional user-provided label for this client.
scope: ScopeThe authorization scopes allowed for this client.