pub struct CreateRevocableClientResponse {
pub user_pk: Option<UserPk>,
pub pubkey: PublicKey,
pub created_at: TimestampMs,
pub eph_ca_cert_der: Vec<u8>,
pub rev_client_cert_der: Vec<u8>,
pub rev_client_cert_key_der: Vec<u8>,
}Expand description
The response to CreateRevocableClientRequest.
Fields
user_pk: Option<UserPk>The user public key associated with these credentials.
Always Some since node-v0.8.11.
pubkey: PublicKeyThe client cert pubkey.
created_at: TimestampMsWhen this client was created.
eph_ca_cert_der: Vec<u8>The DER-encoded ephemeral issuing CA cert that the client should trust.
This is just packaged alongside the rest for convenience.
rev_client_cert_der: Vec<u8>The DER-encoded client cert to present when connecting to the node.
rev_client_cert_key_der: Vec<u8>The DER-encoded client cert key.