RevocableClient

Struct RevocableClient 

pub struct RevocableClient {
    pub pubkey: PublicKey,
    pub created_at: TimestampMs,
    pub expires_at: Option<TimestampMs>,
    pub label: Option<String>,
    pub scope: Scope,
    pub is_revoked: bool,
}
Information about a revocable client. Each client is issued a RevocableClientCert whose pubkey is saved here.

Fields

pubkey: PublicKey

The client’s cert pubkey.

created_at: TimestampMs

When we first issued the client cert and created this client.

expires_at: Option<TimestampMs>

The time after which the server will no longer accept this client. None indicates that the client will never expire (use carefully!). This expiration time can be extended at any time.

label: Option<String>

Optional user-provided label for this client.

scope: Scope

The authorization scopes allowed for this client.

is_revoked: bool

Whether this client has been revoked. Revocation is permanent.

Implementations

Source

impl RevocableClient

pub const MAX_LABEL_LEN: usize = 64

Limit label length to 64 bytes

pub fn is_valid_at(&self, now: TimestampMs) -> bool

Whether the client is valid at a given time (not revoked, not expired).

pub fn is_expired_at(&self, now: TimestampMs) -> bool

Whether the client is expired at the given time.

Source

impl RevocableClient

pub fn update(&self, req: UpdateClientRequest) -> Result<Self>

Apply an update to this client, returning a copy with updates applied.