pub struct RevocableClients {
pub clients: HashMap<PublicKey, RevocableClient>,
}Expand description
All revocable clients which have ever been created.
This struct must be persisted in a rollback-resistant data store.
Fields
clients: HashMap<PublicKey, RevocableClient>Implementations
Sourceimpl RevocableClients
impl RevocableClients
Sourcepub fn iter_valid(&self) -> impl Iterator<Item = (&PublicKey, &RevocableClient)>
pub fn iter_valid(&self) -> impl Iterator<Item = (&PublicKey, &RevocableClient)>
An iterator over all clients which are valid right now.
Sourcepub fn iter_valid_at(
&self,
now: TimestampMs,
) -> impl Iterator<Item = (&PublicKey, &RevocableClient)>
pub fn iter_valid_at( &self, now: TimestampMs, ) -> impl Iterator<Item = (&PublicKey, &RevocableClient)>
An iterator over all clients which are valid at the given time.