UpdateClientRequest

Struct UpdateClientRequest 

pub struct UpdateClientRequest {
    pub pubkey: PublicKey,
    pub expires_at: Option<Option<TimestampMs>>,
    pub label: Option<Option<String>>,
    pub scope: Option<Scope>,
    pub is_revoked: Option<bool>,
}
A request to update a single RevocableClient.

All fields except pubkey are optional. If a field is None, it will not be updated. For example:

  • expires_at: None -> don’t change
  • expires_at: Some(None) -> set to never expire
  • expires_at: Some(TimestampMs(..)) -> set to expire at that time

Fields

pubkey: PublicKey

The pubkey of the client to update.

expires_at: Option<Option<TimestampMs>>

Set this client’s expiration (Some(None) means never expire).

label: Option<Option<String>>

Set this client’s label.

scope: Option<Scope>

Set the authorization scopes allowed for this client.

is_revoked: Option<bool>

Set this to revoke or unrevoke the client. Revocation is permanent, so you cannot unrevoke a client once it is revoked.