Module test_event

Module test_event 

TestEvent.

Enums

TestEvent
Test events emitted throughout the node that allow test to know when something has happened, obviating the need for sleeps (which introduce flakiness) while keeping tests reasonably fast.
TestEventOp
An enum for calling various TestEventReceiver methods.