Module version

Module version 

Data types which relate to node versions: NodeEnclave, MeasurementStruct

Structs

CurrentEnclaves
API-upgradeable struct for a BTreeSet<NodeEnclave>.
EnclavesToProvision
The subset of node enclaves that a specific user needs to provision to.
MeasurementStruct
Upgradeable API struct for a measurement.
NodeEnclave
The machine_id, semver version and measurement of a node enclave.