ToNumBlocks

Trait ToNumBlocks 

pub trait ToNumBlocks {
    // Required method
    fn to_num_blocks(&self) -> u16;
}
Small extension trait to ease interop between our ConfirmationPriority and LDK’s ConfirmationTarget.

Required Methods

fn to_num_blocks(&self) -> u16

Convert a confirmation priority into a target number of blocks.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToNumBlocks for ConfirmationTarget

Implementors