pub struct LxRouteHop {
pub node_pk: NodePk,
pub node_alias: Option<LxNodeAlias>,
pub scid: Scid,
pub fee_or_amount: Amount,
pub announced: bool,
}Expand description
Newtype for RouteHop.
Fields
node_pk: NodePkThe node_id of the node at this hop.
node_alias: Option<LxNodeAlias>The alias of the node at this hop, if known.
scid: ScidThe channel used from the previous hop to reach this node.
fee_or_amount: AmountIf this is NOT the last hop in LxPath::hops, this is the fee taken
on this hop (for paying for the use of the next channel in the path).
If this IS the last hop in LxPath::hops:
- If we’re sending to a blinded payment path, this is the fee paid for use of the entire blinded path.
- Otherwise, this is the amount of this
LxPath’s part of the payment.
announced: boolWhether we believe this channel is announced in the public graph.