pub struct Ppm(/* private fields */);Expand description
A “parts per million” value for proportional fee rates.
Internally stores an i32 in the range [0, 1_000_000].
1_000_000 ppm = 100%, so 5000 ppm = 0.5%.
Implementations
Sourceimpl Ppm
impl Ppm
Sourcepub fn try_from_decimal(rate: Decimal) -> Result<Self, Error>
pub fn try_from_decimal(rate: Decimal) -> Result<Self, Error>
Sourcepub fn try_from_percent(pct: Decimal) -> Result<Self, Error>
pub fn try_from_percent(pct: Decimal) -> Result<Self, Error>
Sourcepub const fn to_decimal(self) -> Decimal
pub const fn to_decimal(self) -> Decimal
Returns the ppm value as a Decimal rate (ppm / 1_000_000).
For example, 5000 ppm becomes 0.005 (0.5%).
Sourcepub const fn to_percent(self) -> Decimal
pub const fn to_percent(self) -> Decimal
Returns the ppm value as a Decimal percentage (ppm / 10_000).
For example, 5000 ppm becomes 0.5 (0.5%).