TimestampMs

Struct TimestampMs 

pub struct TimestampMs(/* private fields */);
A timestamp in milliseconds since the UNIX epoch (January 1, 1970). Serialized as a non-negative integer.

Implementations

Source

impl TimestampMs

pub const MIN: Self

pub const MAX: Self

pub fn now() -> Self

Creates a new TimestampMs from the current SystemTime.

Panics if the current time is not within bounds.

pub fn to_i64(self) -> i64

Get this unix timestamp as an i64 in milliseconds from unix epoch.

pub fn to_u64(self) -> u64

Get this unix timestamp as a u64 in milliseconds from unix epoch.

pub fn from_secs(secs: u64) -> Result<Self, Error>

Construct TimestampMs from seconds since Unix epoch.

pub fn from_secs_u32(secs: u32) -> Self

Infallibly construct TimestampMs from seconds since Unix epoch.

pub fn from_millis(millis: u64) -> Result<Self, Error>

Construct TimestampMs from milliseconds since Unix epoch.

pub fn from_duration(dur_since_epoch: Duration) -> Result<Self, Error>

Construct TimestampMs from Duration since Unix epoch.

pub fn from_system_time(system_time: SystemTime) -> Result<Self, Error>

Construct TimestampMs from a SystemTime.

pub fn to_millis(self) -> u64

Get this unix timestamp as a u64 in milliseconds from unix epoch.

pub fn to_secs(self) -> u64

Get this unix timestamp as a u64 in seconds from unix epoch.

pub fn to_duration(self) -> Duration

Get this unix timestamp as a Duration from the unix epoch.

pub fn to_system_time(self) -> SystemTime

Get this unix timestamp as a SystemTime.

pub fn checked_add(self, duration: Duration) -> Option<Self>

pub fn checked_sub(self, duration: Duration) -> Option<Self>

pub fn saturating_add(self, duration: Duration) -> Self

pub fn saturating_sub(self, duration: Duration) -> Self

pub fn absolute_diff(self, other: Self) -> Duration

Returns the absolute difference two timestamps as a Duration.