Module api

Module api 

API definitions, errors, clients, and structs sent across the wire.

Modules

auth
Authentication and User Signup.
fiat_rates
Data types returned from the fiat exchange rate API. Data types returned from the fiat exchange rate API.
models
API models which don’t fit anywhere else.
provision
Data types specific to provisioning.
revocable_clients
Revocable clients. Information about a client
test_event
TestEvent.
user
User ID-like types: User, UserPk, NodePk, Scid
version
Data types which relate to node versions: NodeEnclave, MeasurementStruct

Structs

MegaIdStruct

Type Aliases

MegaId
A randomly generated id for each mega node.