Authentication and User Signup.
Structs
- Bearer
Auth Request - A client’s request for a new
BearerAuthToken. - Bearer
Auth Request Wire V1 - A user client’s request for auth token with certain restrictions.
- Bearer
Auth Request Wire V2 - A user client’s request for auth token with certain restrictions.
- Bearer
Auth Response - Bearer
Auth Token - An opaque bearer auth token for authenticating user clients against lexe
infra as a particular
UserPk. - Token
With Expiration - A
BearerAuthTokenand its expected expiration time, orNoneif the token never expires. - User
Signup Request Wire V1 - User
Signup Request Wire V2
Enums
- Bearer
Auth Request Wire - A client’s request for a new
BearerAuthToken. - Error
- Scope
- The allowed API scope for the bearer auth token.
- User
Signup Request Wire - The inner, signed part of the request a new user makes when they first sign
up. We use this to prove the user owns both their claimed
UserPkandNodePk.