BearerAuthRequest

Struct BearerAuthRequest 

pub struct BearerAuthRequest {
    pub request_timestamp_secs: u64,
    pub lifetime_secs: u32,
    pub scope: Option<Scope>,
}
A client’s request for a new BearerAuthToken.

This is the convenient in-memory representation.

Fields

request_timestamp_secs: u64

The timestamp of this auth request, in seconds since UTC Unix time, interpreted relative to the server clock. Used to prevent replaying old auth requests after expiration.

The server will reject timestamps w/ > 30 minute clock skew from the server clock.

lifetime_secs: u32

How long the new auth token should be valid for, in seconds. Must be at most 1 hour. The new token expiration is generated relative to the server clock.

scope: Option<Scope>

The allowed API scope for the bearer auth token. If unset, the issued token currently defaults to Scope::All.

Implementations

Source

impl BearerAuthRequest

pub fn new( now: SystemTime, token_lifetime_secs: u32, scope: Option<Scope>, ) -> Self

pub fn request_timestamp(&self) -> Result<SystemTime, Error>

Get the request_timestamp as a SystemTime. Returns Err if the issued_timestamp is too large to be represented as a unix timestamp (> 2^63 on linux).