pub trait GetRevocableClientStatus:
Debug
+ Send
+ Sync {
// Required method
fn get_client_status(
&self,
client_pk: &PublicKey,
now: TimestampMs,
) -> Option<RevocableClientStatus>;
}Expand description
A handshake-time validity check for a revocable client cert.
This trait exists mainly so RevocableClients can live in lexe-api-core
rather than lexe-common.
Implemented by lexe_api_core::revocable_clients::RevocableClientsHandle.
Required Methods
Sourcefn get_client_status(
&self,
client_pk: &PublicKey,
now: TimestampMs,
) -> Option<RevocableClientStatus>
fn get_client_status( &self, client_pk: &PublicKey, now: TimestampMs, ) -> Option<RevocableClientStatus>
The status of the revocable client identified by client_pk at now,
or None if no client with this pubkey exists.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".