TestEvent.
Enums
- Test
Event - Test events emitted throughout the node that allow test to know when something has happened, obviating the need for sleeps (which introduce flakiness) while keeping tests reasonably fast.
- Test
Event Op - An enum for calling various
TestEventReceivermethods.