TestEvent

Enum TestEvent 

pub enum TestEvent {
    FundingGenerationHandled,
    TxBroadcasted,
    ChannelPending,
    ChannelReady,
    PaymentClaimable,
    PaymentClaimed,
    PaymentSent,
    PaymentFailed,
    PaymentRetried,
    ChannelClosed,
    SpendableOutputs,
}
Test events emitted throughout the node that allow test to know when something has happened, obviating the need for sleeps (which introduce flakiness) while keeping tests reasonably fast.

Variants



FundingGenerationHandled

A FundingGenerationReady event was handled.



TxBroadcasted

An on-chain transaction was successfully broadcasted by LexeEsplora.



ChannelPending

A ChannelPending event was handled.



ChannelReady

A ChannelReady event was handled.



PaymentClaimable

A PaymentClaimable event was handled.



PaymentClaimed

A PaymentClaimed event was handled.



PaymentSent

A PaymentSent event was handled.



PaymentFailed

A PaymentFailed event was handled.



PaymentRetried

A payment was enqueued for retry after a transient failure.



ChannelClosed

A ChannelClosed event was handled.



SpendableOutputs

A SpendableOutputs event was handled.