Data types which relate to node versions: NodeEnclave, MeasurementStruct
Structs
- Current
Enclaves - API-upgradeable struct for a
BTreeSet<NodeEnclave>. - Enclaves
ToProvision - The subset of node enclaves that a specific user needs to provision to.
- Measurement
Struct - Upgradeable API struct for a measurement.
- Node
Enclave - The machine_id, semver version and measurement of a node enclave.