Amount

Struct Amount 

pub struct Amount(/* private fields */);
A non-negative Bitcoin amount in satoshis. Serialized as a string-encoded decimal to avoid floating-point precision loss (e.g. "1234.567").

Sub-satoshi precision down to the millisatoshi is supported.

Implementations

Source

impl Amount

pub const MAX: Self

The maximum Amount that this type can represent. We set this exactly equal to u64::MAX millisatoshis because it makes conversions to and from u64 infallible and hence ergonomic, desirable because u64 is the most common representation for millisats in non-Lexe code.

pub const ZERO: Self

An Amount of zero bitcoins.

pub const MAX_BITCOIN_SUPPLY: Self

The maximum supply of Bitcoin that can ever exist. Analogous to bitcoin::Amount::MAX_MONEY; primarily useful as a sanity check.

pub const MAX_BITCOIN_SUPPLY_SATS_U64: u64 = 21_000_000_0000_0000

pub const MAX_BITCOIN_SUPPLY_MSATS_U64: u64 = 21_000_000_0000_0000_000

pub const INVOICE_MAX_AMOUNT_MSATS_U64: u64

The maximum amount we can set in a BOLT11 invoice via the LDK lightning_invoice::InvoiceBuilder::amount_milli_satoshis API. Setting above this value will overflow!

pub fn from_msat(msats: u64) -> Self

Construct an Amount from a millisatoshi u64 value.

pub fn from_sats_u32(sats_u32: u32) -> Self

Construct an Amount from a satoshi u32 value.

pub fn try_from_sats_u64(sats_u64: u64) -> Result<Self, Error>

Construct an Amount from a satoshi u64 value.

pub fn try_from_sats(sats: Decimal) -> Result<Self, Error>

Construct an Amount from a satoshi Decimal value.

pub fn try_from_btc(btc: Decimal) -> Result<Self, Error>

Construct an Amount from a BTC Decimal value.

pub fn msat(&self) -> u64

Returns the Amount as a u64 millisatoshi value.

pub fn invoice_safe_msat(&self) -> Result<u64, Error>

Returns the Amount as a u64 millisatoshi value, but safe to use when building a BOLT11 lightning invoice.

pub fn sats_u64(&self) -> u64

Returns the Amount as a u64 satoshi value.

pub fn sats(&self) -> Decimal

Returns the Amount as a Decimal satoshi value.

pub fn btc(&self) -> Decimal

Returns the Amount as a Decimal BTC value.

pub fn round_sat(&self) -> Self

Rounds to the nearest satoshi.

e.g. 123.456 sats => 123 sats

pub fn floor_sat(&self) -> Self

Rounds to the nearest satoshi, rounding towards zero.

pub fn abs_diff(self, other: Self) -> Amount

Returns the absolute difference |x-y| between two Amounts.

pub fn approx_eq(self, other: Self, epsilon: Self) -> bool

Returns true if two amounts are approximately equal, up to some epsilon max difference.

pub fn checked_add(self, rhs: Self) -> Option<Self>

pub fn checked_sub(self, rhs: Self) -> Option<Self>

pub fn checked_mul(self, rhs: Decimal) -> Option<Self>

pub fn checked_div(self, rhs: Decimal) -> Option<Self>

pub fn saturating_add(self, rhs: Self) -> Self

pub fn saturating_sub(self, rhs: Self) -> Self

pub fn saturating_mul(self, rhs: Decimal) -> Self