#[repr(transparent)]pub struct LxUserChannelId(pub [u8; 16]);Expand description
See: lightning::ln::channel_state::ChannelDetails::user_channel_id
The user channel id lets us consistently identify a channel through its whole lifecycle.
The main issue is that we don’t know the LxChannelId until we’ve
actually talked to the remote node and agreed to open a channel. The second
issue is that we can’t easily observe and correlate any errors from channel
negotiation beyond some basic checks before we send any messages.
Tuple Fields
0: [u8; 16]Implementations
Sourceimpl LxUserChannelId
impl LxUserChannelId
pub fn to_u128(self) -> u128
pub fn from_rng<R: RngCore>(rng: &mut R) -> Self
pub fn derive_temporary_channel_id(&self) -> LxChannelId