ToNumBlocks

Trait ToNumBlocks 

pub trait ToNumBlocks {
    // Required method
    fn to_num_blocks(&self) -> u16;
}
Small extension trait to ease interop between our ConfirmationPriority and LDK’s ConfirmationTarget.

Required Methods

fn to_num_blocks(&self) -> u16

Convert a confirmation priority into a target number of blocks.

Implementations on Foreign Types

Source

impl ToNumBlocks for ConfirmationTarget

Implementors