pub struct TimestampMs(/* private fields */);Expand description
A timestamp in milliseconds since the UNIX epoch (January 1, 1970). Serialized as a non-negative integer.
Implementations
Sourceimpl TimestampMs
impl TimestampMs
pub const MIN: Self
pub const MAX: Self
Sourcepub fn now() -> Self
pub fn now() -> Self
Creates a new TimestampMs from the current SystemTime.
Panics if the current time is not within bounds.
Sourcepub fn from_secs(secs: u64) -> Result<Self, Error>
pub fn from_secs(secs: u64) -> Result<Self, Error>
Construct TimestampMs from seconds since Unix epoch.
Sourcepub fn from_secs_u32(secs: u32) -> Self
pub fn from_secs_u32(secs: u32) -> Self
Infallibly construct TimestampMs from seconds since Unix epoch.
Sourcepub fn from_millis(millis: u64) -> Result<Self, Error>
pub fn from_millis(millis: u64) -> Result<Self, Error>
Construct TimestampMs from milliseconds since Unix epoch.
Sourcepub fn from_duration(dur_since_epoch: Duration) -> Result<Self, Error>
pub fn from_duration(dur_since_epoch: Duration) -> Result<Self, Error>
Construct TimestampMs from Duration since Unix epoch.
Sourcepub fn from_system_time(system_time: SystemTime) -> Result<Self, Error>
pub fn from_system_time(system_time: SystemTime) -> Result<Self, Error>
Construct TimestampMs from a SystemTime.
Sourcepub fn to_millis(self) -> u64
pub fn to_millis(self) -> u64
Get this unix timestamp as a u64 in milliseconds from unix epoch.
Sourcepub fn to_duration(self) -> Duration
pub fn to_duration(self) -> Duration
Get this unix timestamp as a Duration from the unix epoch.
Sourcepub fn to_system_time(self) -> SystemTime
pub fn to_system_time(self) -> SystemTime
Get this unix timestamp as a SystemTime.
pub fn checked_add(self, duration: Duration) -> Option<Self>
pub fn checked_sub(self, duration: Duration) -> Option<Self>
pub fn saturating_add(self, duration: Duration) -> Self
pub fn saturating_sub(self, duration: Duration) -> Self
Sourcepub fn absolute_diff(self, other: Self) -> Duration
pub fn absolute_diff(self, other: Self) -> Duration
Returns the absolute difference two timestamps as a Duration.